@@ -150,6 +150,7 @@ string LoTWDir = "";
 string KmlDir = "";
 string PskMailDir = "";
 string AnalysisDir = "";
+string FMTDir = "";
 
 string NBEMS_dir = "";
 string NBEMS_dir_default = "";
@@ -1054,6 +1055,7 @@ int main(int argc, char ** argv)
 	LOG_INFO("LoTWDir: %s", LoTWDir.c_str());
 	LOG_INFO("MacrosDir: %s", MacrosDir.c_str());
 	LOG_INFO("AnalysisDir: %s", AnalysisDir.c_str());
+	LOG_INFO("FMTDir: %s", FMTDir.c_str());
 	LOG_INFO("PalettesDir: %s", PalettesDir.c_str());
 	LOG_INFO("PicsDir: %s", PicsDir.c_str());
 	LOG_INFO("PskMailDir: %s", PskMailDir.c_str());
@@ -1213,6 +1215,9 @@ int main(int argc, char ** argv)
 	}
 	kml_init(true);
 
+	if (progdefaults.kml_purge_on_startup)
+		KmlServer::GetInstance()->Reset();
+
 // OS X will prevent the main window from being resized if we change its
 // size *after* it has been shown. With some X11 window managers, OTOH,
 // the main window will not be restored at its exact saved position if
@@ -1243,9 +1248,7 @@ int main(int argc, char ** argv)
 
 	Fl::set_color(FL_SELECTION_COLOR, 0, 0, 128);
 
-	int ret = Fl::run();
-
-	return ret;
+	return  Fl::run();
 }
 
 void exit_process() {
@@ -2074,6 +2077,7 @@ static void checkdirectories(void)
 		{ HelpDir, "help", 0 },
 		{ MacrosDir, "macros", create_new_macros },
 		{ AnalysisDir, "analysis", 0 },
+		{ FMTDir, "fmt", 0 },
 		{ WrapDir, "wrap", 0 },
 		{ TalkDir, "talk", 0 },
 		{ TempDir, "temp", 0 },
@@ -2207,9 +2211,8 @@ void kml_init(bool load_files)
 			progdefaults.kml_refresh_interval,
 			progdefaults.kml_balloon_style);
 
-	if(load_files) {
+	if (load_files)
 		KmlServer::GetInstance()->ReloadKmlFiles();
-	}
 
 	/// TODO: Should do this only when the locator has changed.
 	try {
